Learn R Programming

BayesDA (version 1.0-0)

cow: Data from an Experiment with Treatment Assignment Based on Covariates

Description

An experiment was conducted on 50 cows to estimate the effect of a feed additive (methionine hydroxy analog) on six outcomes related to the amount of milk fat produced by each cow. Four diets (treatments) were considered, corresponding to different levels of the additive, and three variables were recorded before treatment assignment: lactation number ( seasons of lactation), age, and initial weight of cow. Multiple randomizations were calculated, and choosen that one with `best balane', however that was defined.

Usage

data(cow)

Arguments

docType

data

concept

randomization

Examples

Run this code
data(cow)
summary(cow)
names(cow)
# Investigating balance on pretreatment variables:
with(cow, tapply(lactation, level, mean))
with(cow, tapply(age, level, mean))

Run the code above in your browser using DataLab