Learn R Programming

BayesDA (version 1.0-0)

phones: CBS Telephone Survey

Description

Respondents to the CBS telephone survey classified by opinion, number of residential telephone lines, and number of adults in the household.

Usage

data(phones)

Arguments

docType

data

Details

This is used in exercises pages 242--243 in the book.

Examples

Run this code
data(phones)     
summary(phones)

Run the code above in your browser using DataLab